@@ -1,8 +1,18 @@
 from botocore.exceptions import ClientError
 from tqdm import tqdm
+from typing import Any, Tuple
 
 
-def truncate(table):
+def truncate(table: Any) -> Tuple:
+    """DynamoDB table truncate
+
+    Args:
+        table (Any): boto3 DynamoDB table object
+
+    Returns:
+        Tuple: result message and exit code
+    """
+
     # all scan delete items
     delete_items = []
     parameters = {}
@@ -16,9 +26,9 @@ def truncate(table):
             else:
                 break
     except ClientError:
-        return "aws client error"
+        return ("aws client error", 1)
     except Exception:
-        return "table not found"
+        return ("table not found", 1)
 
     print("{name} scan {count} items".format(
         name=table.name, count=len(delete_items)))
@@ -26,7 +36,7 @@ def truncate(table):
     # get key attribute name and item delete keys
     key_names = [x["AttributeName"] for x in table.key_schema]
     delete_keys = [{k: v for k, v in x.items() if k in key_names}
-                   for x in delete_items]
+                for x in delete_items]
 
     # delete all items
     with table.batch_writer() as batch:
@@ -35,4 +45,4 @@ def truncate(table):
         for key in tqdm(delete_keys):
             batch.delete_item(Key=key)
 
-    return "{name} truncated".format(name=table.name)
+    return ("{name} truncated".format(name=table.name), 0)
